@@ -5,12 +5,10 @@ class HAPIError(Exception):
         self.code = code
 
     def __str__(self):
-        return repr(
-            "{msg} -- HubSpot API responded with: {response} - code {code}".format(
-                msg=self.message,
-                response=self.response,
-                code=self.code
-            )
+        return "{msg} -- HubSpot API responded with: {response} - code {code}".format(
+            msg=self.message,
+            response=self.response,
+            code=self.code
         )
 
 class HSApi:
