@@ -18,20 +18,24 @@ class Properties(HSApi):
         r = requests.get(self.PROPERTIES_URL, params=params)
         if r.status_code == 200:
             return r.json()
-        else:
-            raise HAPIError(
-                message="Properties Get All Method Failed",
-                response=r.text,
-                code=r.status_code
-            )
 
-    def get(self, name, target=None):
-        if not target:
-            target = self.get_all()
-        for prop in target:
-            if prop["name"] == name:
-                return prop
-        return False
+        raise HAPIError(
+            message="Properties Get All Method Failed",
+            response=r.text,
+            code=r.status_code
+        )
+
+    def get_by_name(self, name):
+        r = requests.get(self.PROPERTIES_URL + name, params = self.add_authentication({}))
+
+        if r.status_code == 200:
+            return r.json()
+
+        raise HAPIError(
+            message="Properties Get by name Method Failed",
+            response=r.text,
+            code=r.status_code
+        )
 
     def create_property(self, hsproperty=None, **kwargs):
         if not isinstance(hsproperty, HSProperty):
@@ -51,28 +55,25 @@ class Properties(HSApi):
         else:
             return False
 
-    def update_property(self, hsproperty=None, **kwargs):
-        if not isinstance(hsproperty, HSProperty):
-            name = kwargs.get("name")
-            if not name:
-                raise SyntaxError("you must supply a name value")
-            hsproperty = HSProperty.from_json(self.get(name))
+    def update_property(self, name, data):
 
-        hsproperty.update(**kwargs)
-
-        url = self.PROPERTIES_URL + hsproperty.name
+        url = self.PROPERTIES_URL + name
 
         r = requests.post(
             url,
             params=self.add_authentication({}),
-            data=hsproperty.to_json(),
+            data=data,
             headers={'content-type': 'application/json'}
         )
 
         if r.status_code is 200:
             return True
-        else:
-            return False
+
+        raise HAPIError(
+            message="Properties Update Method Failed",
+            response=r.text,
+            code=r.status_code
+        )
 
     def delete_property(self, name):
         url = self.PROPERTIES_URL + name
